geowatch.cli.smartflow.run\_bas\_datagen module
===============================================

.. automodule:: geowatch.cli.smartflow.run_bas_datagen
   :members:
   :undoc-members:
   :show-inheritance:
